context("Testing Load with ECMWF System5c3s daily data")
test_that("First time step is correctly interpreted:", {
  data <- Load(var = 'prlr',
               exp = list(list(name = 'ecmwfS5', path = "/esarchive/exp/ecmwf/system5c3s/$STORE_FREQ$_mean/$VAR_NAME$_s0-24h/$VAR_NAME$_$START_DATE$.nc")),
               obs = list(list(name = 'era5', path = '/esarchive/recon/ecmwf/era5/$STORE_FREQ$_mean/$VAR_NAME$_f1h-r1440x721cds/$VAR_NAME$_$YEAR$$MONTH$.nc')),
               sdates = c('19931101', '19941101'), #paste0(1993:2018, '1101')
               nmember = 25,leadtimemin = 1,
               leadtimemax = NULL,
               storefreq = "daily", sampleperiod = 1,
               latmin = 42, latmax = 49, lonmin = 4, lonmax = 11,
               output = 'lonlat', nprocs = 1,
               method = 'conservative', grid = 'r360x181',
               maskmod = vector("list", 15), maskobs = vector("list", 15),
               configfile = NULL, varmin = NULL, varmax = NULL,
               silent = FALSE, dimnames = NULL,
               remapcells = 2, path_glob_permissive = 'partial',
               nmemberobs = NULL, nleadtime = NULL)
  expect_equal(dim(data$mod), c(dataset = 1, member = 25, sdate = 2, ftime = 214, 
                                lat = 8, lon = 8))
  expect_equal(dim(data$obs), c(dataset = 1, member = 1, sdate = 2, ftime = 214,
                                lat = 8, lon = 8))
  expect_equal(sum(is.na(data$mod)), 0)
  expect_equal(sum(is.na(data$obs)), 0)
  dates <- c(seq(as.POSIXct("1993-11-02", tz = 'UTC'), 
                                       as.POSIXct("1994-06-03", tz = 'UTC'), "d"),
                                   seq(as.POSIXct("1994-11-02", tz = 'UTC'),
                                       as.POSIXct("1995-06-03", tz = 'UTC'), "d"))
  attributes(dates)$tzone <- 'UTC'
  expect_equal(data$Dates$start, dates)
  dates <- c(seq(as.POSIXct("1993-11-03", tz = 'UTC'),
                 as.POSIXct("1994-06-04", tz = 'UTC'), "d"),
             seq(as.POSIXct("1994-11-03", tz = 'UTC'),
                 as.POSIXct("1995-06-04", tz = 'UTC'), "d"))
  attributes(dates)$tzone <- 'UTC'
  expect_equal(data$Dates$end, dates)
  
  obs <- s2dverification::Load(var = 'prlr', exp = NULL,
                               obs = list(list(name = 'era5', path = '/esarchive/recon/ecmwf/era5/$STORE_FREQ$_mean/$VAR_NAME$_f1h-r1440x721cds/$VAR_NAME$_$YEAR$$MONTH$.nc')),
                               sdates = c('19931101', '19941101'),
                               #paste0(1993:2018, '1101')
                               nmember = 25,leadtimemin = 1,
                               leadtimemax = 2,
                               storefreq = "daily", sampleperiod = 1,
                               latmin = 42, latmax = 49, lonmin = 4, lonmax = 11,
                               output = 'lonlat', nprocs = 1,
                               method = 'conservative', grid = 'r360x181',
                               maskmod = vector("list", 15), maskobs = vector("list", 15),
                               configfile = NULL, varmin = NULL, varmax = NULL,
                               silent = FALSE, dimnames = NULL,
                               remapcells = 2, path_glob_permissive = 'partial',
                               nmemberobs = 1, nleadtime = NULL)
  # The values of observation when loading exp and obs simultaneously corresponds to the second day of the observations in the file:
  expect_equal(data$obs[1,1,1,1,,], obs$obs[1,1,1,2,,])
  expect_equal(data$obs[1,1,2,1,,], obs$obs[1,1,2,2,,]) 
  

  
  
})